Contributors
------------

- Anton Ostapenko <olsnod@gmail.com>
- Ivan Mikhailov <mikhailov@angrydev.ru>
- Andrey Zakharov <andrey.v.zakharov@yandex.ru>
- WhiteApfel <white@pfel.ru>


Thanks also to
--------------
